@@ -83,8 +83,8 @@ class Metric:
         if self.ref:
             message += f"Ref: {self.ref}\n"
         if self.value:
-            message += f"Value: {self.value}"
-        message += f"First Seen: {self._prettify_created_at()}"
+            message += f"Value: {self.value}\n"
+        message += f"First Seen: {self._prettify_created_at()}\n"
         if self.checked:
             message += "Checked\n"
         if self.annotations:
