@@ -1,7 +1,13 @@
 """A Rule takes data from sources, makes metrics and puts them into stores."""
 from __future__ import annotations
 
-from sinai.types import Evaluation, MonitorInstance, SourceClasses, StoreClasses
+from sinai.types import (
+    Evaluation,
+    MonitorInstance,
+    SourceClasses,
+    SourceInstance,
+    StoreClasses,
+)
 
 
 class Rule:
@@ -13,6 +19,6 @@ class Rule:
     def __init__(self, monitor: MonitorInstance):
         self.monitor = monitor
 
-    def evaluate(self) -> Evaluation:
+    def evaluate(self, *sources: SourceInstance) -> Evaluation:
         """The evalutation function is called by the monitor, which stores any returned metrics."""
         return None
