@@ -6,10 +6,12 @@ __all__ = [
     "ApiStore",
     "CloudWatch",
     "Slack",
+    "DebugStore",
 ]
 from sinai.stores.api import ApiStore
 from sinai.stores.base import MetricStore, Store
 from sinai.stores.cloudwatch import CloudWatch
+from sinai.stores.debug import DebugStore
 from sinai.stores.memory import MemoryMetricStore
 from sinai.stores.mongo import MongoMetricStore
 from sinai.stores.slack import Slack
