@@ -73,6 +73,8 @@ GlobalMemory = Dict[MetricId, JDict]
 # Rule types
 RuleClass = Type["Rule"]
 RuleClasses = List[RuleClass]
+RuleInstance: TypeAlias = "Rule"
+RuleInstances: Sequence[RuleInstance]
 
 # Store types
 StoreClass = Type["Store"]
@@ -82,17 +84,18 @@ StoreClasses = Sequence[StoreClass]
 
 # Source types
 SourceInstance: TypeAlias = "Source"
+SourceInstances = Sequence[SourceInstance]
 SourceClass = Type[SourceInstance]
 SourceClassList = List[SourceClass]
 SourceDict = Dict[SourceClass, SourceInstance]
 SourceClasses = Sequence[SourceClass]
+OptionalSourceInstances = Union[Sequence[SourceInstance], None]
 
 # MetricSource types
 MetricSourceInstance: TypeAlias = "MetricSource"
 MetricSourceClass = Type[MetricSourceInstance]
 MetricSourceClasses = Sequence[MetricSourceClass]
 
-
 # ApiSource types
 RequestHeader = Dict[str, str]
 
